<?php

class ControllerExtensionPaymentVepay extends Controller
{
    private $error = [];

    public function index()
    {
        $this->load->language('extension/payment/vepay');
        $this->load->model('setting/setting');

        $this->document->setTitle($this->language->get('heading_title'));

        if (($this->request->server['REQUEST_METHOD'] == 'POST') && $this->validate()) {
            $this->model_setting_setting->editSetting('payment_vepay', $this->request->post);
            $this->session->data['success'] = $this->language->get('text_success');

            $this->response->redirect($this->url->link('marketplace/extension', 'user_token=' . $this->session->data['user_token'] . '&type=payment', true));
        }

        $data['action'] = $this->url->link('extension/payment/vepay', 'user_token=' . $this->session->data['user_token'], true);

        if (isset($this->error['warning'])) {
            $data['error_warning'] = $this->error['warning'];
        } else {
            $data['error_warning'] = '';
        }

        if (isset($this->error['error_merch_id'])) {
            $data['error_merch_id'] = $this->error['error_merch_id'];
        } else {
            $data['error_merch_id'] = '';
        }

        if (isset($this->error['error_merch_token'])) {
            $data['error_merch_token'] = $this->error['error_merch_token'];
        } else {
            $data['error_merch_token'] = '';
        }

        if (isset($this->error['error_callback_token'])) {
            $data['error_callback_token'] = $this->error['error_callback_token'];
        } else {
            $data['error_callback_token'] = '';
        }

        $data['breadcrumbs'] = array();

        $data['breadcrumbs'][] = array(
            'text' => $this->language->get('text_home'),
            'href' => $this->url->link('common/dashboard', 'user_token=' . $this->session->data['user_token'], true)
        );

        $data['breadcrumbs'][] = array(
            'text' => $this->language->get('text_payment'),
            'href' => $this->url->link('marketplace/extension', 'user_token=' . $this->session->data['user_token'] . '&type=payment', true)
        );

        $data['breadcrumbs'][] = array(
            'text' => $this->language->get('heading_title'),
            'href' => $this->url->link('extension/payment/vepay', 'user_token=' . $this->session->data['user_token'], true)
        );

        if (isset($this->request->post['payment_vepay_merch_id'])) {
            $data['payment_vepay_merch_id'] = $this->request->post['payment_vepay_merch_id'];
        } else {
            $data['payment_vepay_merch_id'] = $this->config->get('payment_vepay_merch_id');
        }

        if (isset($this->request->post['payment_vepay_merch_token'])) {
            $data['payment_vepay_merch_token'] = $this->request->post['payment_vepay_merch_token'];
        } else {
            $data['payment_vepay_merch_token'] = $this->config->get('payment_vepay_merch_token');
        }

        $data['payment_vepay_callback_url'] = HTTPS_CATALOG . 'index.php?route=extension/payment/vepay/result';

        if (isset($this->request->post['payment_vepay_callback_token'])) {
            $data['payment_vepay_callback_token'] = $this->request->post['payment_vepay_callback_token'];
        } else {
            $data['payment_vepay_callback_token'] = $this->config->get('payment_vepay_callback_token');
        }

        if (isset($this->request->post['payment_vepay_order_status_id'])) {
            $data['payment_vepay_order_status_id'] = $this->request->post['payment_vepay_order_status_id'];
        } else {
            $data['payment_vepay_order_status_id'] = $this->config->get('payment_vepay_order_status_id');
        }

        if (isset($this->request->post['payment_vepay_status'])) {
            $data['payment_vepay_status'] = $this->request->post['payment_vepay_status'];
        } else {
            $data['payment_vepay_status'] = $this->config->get('payment_vepay_status');
        }

        $this->load->model('localisation/order_status');
        $data['order_statuses'] = $this->model_localisation_order_status->getOrderStatuses();

        $data['header'] = $this->load->controller('common/header');
        $data['column_left'] = $this->load->controller('common/column_left');
        $data['footer'] = $this->load->controller('common/footer');

        $this->response->setOutput($this->load->view('extension/payment/vepay', $data));
    }

    private function validate()
    {
        if (!$this->user->hasPermission('modify', 'extension/payment/vepay')) {
            $this->error['warning'] = $this->language->get('error_permission');
        }

        if (!$this->request->post['payment_vepay_merch_id']) {
            $this->error['error_merch_id'] = $this->language->get('error_merch_id');
        }

        if (!$this->request->post['payment_vepay_merch_token']) {
            $this->error['error_merch_token'] = $this->language->get('error_merch_token');
        }

        if (!$this->request->post['payment_vepay_callback_token']) {
            $this->error['error_callback_token'] = $this->language->get('error_callback_token');
        }

        return !$this->error;
    }
}
